@@ -9,8 +9,6 @@ print "Importing sys"
 import sys
 print "Importing os"
 import os
-print "importing gobject"
-import gobject
 print "Importing dbus"
 import dbus
 
